@@ -22,7 +22,7 @@
 # marcelo.goulart@inc.saude.gov.br
 # mgoulart.inc@gmail.com
 
-# last modified: 2014-12-05 by M.G. Correia
+# last modified: 2015-09-08 by M.G. Correia
 
 .onAttach <- function(libname, pkgname){
     if (!interactive()) return()
@@ -45,15 +45,9 @@
 }
 
 RunMTCModel <- function(){
-
-    modelsVariable = NULL
-    rm(modelsVariable)
-    output_mA = NULL
-    rm(output_mA)
-    modelsFrame = NULL
-    rm(modelsFrame)
     Library('runjags')
     Library('rmeta')
+    Library('coda')
     defaults <- list(ArmsVar="", TreatVar="", StudVar="", ChainsVar="4", SimsVar="10000", BurnInVar="4000", models="fem")
     dialog.values <- getDialog("RunMTCModel", defaults)
     initializeDialog(title=gettextRcmdr("Setting up MTC model"))
@@ -126,14 +120,14 @@ RunMTCModel <- function(){
 	modelValue <- trim.blanks(tclvalue(modelName))
 		if (!is.valid.name(modelValue)) {
 			UpdateModelNumber(-1)
-			errorCondition(recall = RunMTCModel, message = sprintf(gettextRcmdr("\"%s\" is not a valid name."), 
+			errorCondition(recall = linearRegressionModel, message = sprintf(gettextRcmdr("\"%s\" is not a valid name."), 
 							modelValue))
 			return()
 		}
 		if (is.element(modelValue, listLinearModels())) {
 			if ("no" == tclvalue(checkReplace(modelValue, type = gettextRcmdr("Model")))) {
 				UpdateModelNumber(-1)
-				RunMTCModel()
+				linearRegressionModel()
 				return()
 			}
 		}
@@ -170,10 +164,10 @@ RunMTCModel <- function(){
 
 	if(models=="fem")
 		{
-		Teste_fem <- paste("Model <- 'model{", "for(i in 1:N){", "logit(p[s[i],t[i]]) <- mu[s[i]] + d[t[i]] - d[b[i]]",
+		Teste <- paste("Model <- 'model{", "for(i in 1:N){", "logit(p[s[i],t[i]]) <- mu[s[i]] + d[t[i]] - d[b[i]]",
 		"r[i]~dbin(p[s[i],t[i]],n[i])}", "for(j in 1:NS){", "mu[j]~dnorm(0,.0001)}", "for (k in 2:NT){", 
 		"d[k] ~ dnorm(0,.0001)}", "d[1] <- 0", output_mA, "for (l in 1:NT) { logit(T[l]) <- mA + d[l] }}'", sep = "\n")
-		doItAndPrint(Teste_fem)
+		doItAndPrint(Teste)
 		command <- paste(modelValue," <- run.jags(model=Model, monitor=c('d','T'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b,'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux <- paste(modelValue,"_aux <- run.jags(model=Model, monitor=c('T'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b,'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux2 <- paste(modelValue,"_aux2 <- run.jags(model=Model, monitor=c('d'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b,'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
@@ -181,10 +175,10 @@ RunMTCModel <- function(){
 
 	if(models=="rem")
 		{
-		Teste_rem <- paste("Model <- 'model{", "for(i in 1:N){", "logit(p[i])<-mu[s[i]]+delta[i]  * (1-equals(t[i],b[i]))",
+		Teste <- paste("Model <- 'model{", "for(i in 1:N){", "logit(p[i])<-mu[s[i]]+delta[i]  * (1-equals(t[i],b[i]))",
 	        "r[i]~dbin(p[i],n[i])", "delta[i] ~ dnorm(md[i],tau)","md[i] <-	d[t[i]] - d[b[i]]}","for(j in 1:NS){ mu[j]~dnorm(0,.0001) }",
 		"d[1]<-0","for (k in 2:NT)  {d[k] ~ dnorm(0,.0001) }","sd~dunif(0,2)","tau<-1/pow(sd,2)",output_mA,"for (k in 1:NT) { logit(T[k])<- mA +d[k] }}'", sep ="\n")
-		doItAndPrint(Teste_rem)
+		doItAndPrint(Teste)
 		command <- paste(modelValue," <- run.jags(model=Model, monitor=c('d','T'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b,'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux <- paste(modelValue,"_aux <- run.jags(model=Model, monitor=c('T'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b,'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux2 <- paste(modelValue,"_aux2 <- run.jags(model=Model, monitor=c('d'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b,'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
@@ -192,11 +186,11 @@ RunMTCModel <- function(){
 
 	if(models=="threerem")
 		{
-		Teste_threerem <- paste("Model <- 'model{","sw[1] <- 0","for(i in 1:N)  {","logit(p[i])<-mu[s[i]]+ delta[i]  * (1-equals(t[i],b[i]))",
+		Teste <- paste("Model <- 'model{","sw[1] <- 0","for(i in 1:N)  {","logit(p[i])<-mu[s[i]]+ delta[i]  * (1-equals(t[i],b[i]))",
 		"r[i]~dbin(p[i],n[i])","delta[i] ~ dnorm(md[i],taud[i])","taud[i] <- tau * (1 + equals(m[i],3) /3)","md[i] <- d[t[i]] - d[b[i]]  +  equals(m[i],3) * sw[i]}",
 		"for (i in 2:N)  {sw[i] <- (delta[i-1] -  d[t[i-1]] + d[b[i-1]])/2}","for(j in 1:NS){ mu[j]~dnorm(0,.0001) }","d[1]<-0",
 		"for (k in 2:NT)  {d[k] ~ dnorm(0,.0001) }","sd~dunif(0,2)","tau<-1/pow(sd,2)",output_mA,"for (k in 1:NT)   { logit(T[k])<- mA  +d[k] }}'", sep="\n")
-		doItAndPrint(Teste_threerem)
+		doItAndPrint(Teste)
 		command <- paste(modelValue," <- run.jags(model=Model, monitor=c('d','T'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b, 'm'=",ActiveDataSet(),"$m, 'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux <- paste(modelValue,"_aux <- run.jags(model=Model, monitor=c('T'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b, 'm'=",ActiveDataSet(),"$m, 'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux2 <- paste(modelValue,"_aux2 <- run.jags(model=Model, monitor=c('d'), n.chains=", Chain, ", method='rjags', data = list('s'=",ActiveDataSet(),"$s, 't'=",ActiveDataSet(),"$t, 'r'=",ActiveDataSet(),"$r, 'n'=",ActiveDataSet(),"$n, 'b'=",ActiveDataSet(),"$b, 'm'=",ActiveDataSet(),"$m, 'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
@@ -207,13 +201,13 @@ RunMTCModel <- function(){
 		justDoIt(paste('n <- as.matrix(',ActiveDataSet(),'[,substr(colnames(',ActiveDataSet(),'), 1, 2) == "n."])', sep = ""))
 		justDoIt(paste('t <- as.matrix(',ActiveDataSet(),'[,substr(colnames(',ActiveDataSet(),'), 1, 2) == "t."])', sep = ""))
 		justDoIt(paste('r <- as.matrix(',ActiveDataSet(),'[,substr(colnames(',ActiveDataSet(),'), 1, 2) == "r."])', sep = ""))
-		Teste_marem <- paste("Model <- 'model{","for(i in 1:NS){","w[i,1] <-0","delta[i,t[i,1]]<-0","mu[i] ~ dnorm(0,.0001)","for (k in 1:na[i])  {",
+		Teste <- paste("Model <- 'model{","for(i in 1:NS){","w[i,1] <-0","delta[i,t[i,1]]<-0","mu[i] ~ dnorm(0,.0001)","for (k in 1:na[i])  {",
 	        "r[i,k] ~ dbin(p[i,t[i,k]],n[i,k])","logit(p[i,t[i,k]])<-mu[i] + delta[i,t[i,k]] }","for (k in 2:na[i]) {",
                 "delta[i,t[i,k]] ~ dnorm(md[i,t[i,k]],taud[i,t[i,k]])","md[i,t[i,k]] <-  d[t[i,k]] - d[t[i,1]]  + sw[i,k]",
-                "taud[i,t[i,k]] <- tau *2*(k-1)/k","w[i,k] <- (delta[i,t[i,k]]  - d[t[i,k]] + d[t[i,1]])","sw[i,k] <-sum(w[i,1:k-1])/(k-1) }}", 					 
+                "taud[i,t[i,k]] <- tau *2*(k-1)/k","w[i,k] <- (delta[i,t[i,k]]  - d[t[i,k]] + d[t[i,1]])","sw[i,k] <-sum(w[i,1:(k-1)])/(k-1) }}", 					 
                 "d[1]<-0","for (k in 2:NT){d[k] ~ dnorm(0,.0001) }","sd~dunif(0,2)","tau<-1/pow(sd,2)",output_mA,
 		"for (k in 1:NT)   { logit(T[k])<- mA  +d[k] }}'", sep="\n")
-		doItAndPrint(Teste_marem)
+		doItAndPrint(Teste)
 		command <- paste(modelValue," <- run.jags(model=Model, monitor=c('d','T'), n.chains=", Chain, ", method='rjags', data = list('t'=t, 'r'=r, 'n'=n, 'na'=",ActiveDataSet(),"$na, 'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux <- paste(modelValue,"_aux <- run.jags(model=Model, monitor=c('T'), n.chains=", Chain, ", method='rjags', data = list('t'=t, 'r'=r, 'n'=n, 'na'=",ActiveDataSet(),"$na, 'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
 		command_aux2 <- paste(modelValue,"_aux2 <- run.jags(model=Model, monitor=c('d'), n.chains=", Chain, ", method='rjags', data = list('t'=t, 'r'=r, 'n'=n, 'na'=",ActiveDataSet(),"$na, 'N'=",Arms,",'NS'=",Stud,",'NT'=",Treat,"), burnin =", BurnIn, ",sample =", Sims,",silent.jags=T",")", sep="")
@@ -257,6 +251,7 @@ SummaryModel <- function(){
     modelName <- tclVar(paste("MTCModel.", "1", sep = ""))
     modelFrame <- tkframe(top)    
     model <- ttkentry(modelFrame, width = "20", textvariable = modelName) 
+    UpdateModelNumber()
 
     onOK <- function(){
         modelValue <- trim.blanks(tclvalue(modelName))
@@ -282,10 +277,6 @@ SummaryModel <- function(){
 
 BestStrat <- function(){
 
-    outcomeVariable = NULL
-    rm(outcomeVariable)
-    outcomeFrame = NULL
-    rm(outcomeFrame)
     initializeDialog(title=gettextRcmdr("Check for best strategy"))
     modelName <- tclVar(paste("MTCModel.", "1", sep = ""))
     modelFrame <- tkframe(top)    
@@ -327,6 +318,92 @@ BestStrat <- function(){
     dialogSuffix()
 	                }
 
+#BestStrat <- function(){
+
+#   initializeDialog(title=gettextRcmdr("Check for best strategy"))
+#    modelName <- tclVar(paste("MTCModel.", "1", sep = ""))
+#    modelFrame <- tkframe(top)    
+#    model <- ttkentry(modelFrame, width = "20", textvariable = modelName)
+    #defaults <- list(TreatVar="")
+    #detailVariable <- tclVar("1")
+    #detailCheckBox <- ttkcheckbutton(optionsFrame, variable=detailVariable)
+    #TreatVar <- tclVar(dialog.values$TreatVar)
+    #TreatEntry <- tkentry(top, width="6", textvariable=TreatVar)
+#    radioButtons(name="outcome", buttons=c("favor","unfavor"), labels=gettextRcmdr(c("Favorable", "Unfavoravle")), title=gettextRcmdr("Outcome"))     
+#
+#    onOK <- function(){
+#        modelValue <- trim.blanks(tclvalue(modelName))
+#        closeDialog()      
+#        if (!is.valid.name(modelValue)){
+#      	    errorCondition(recall=BestStrat, message=sprintf(gettextRcmdr('"%s" is not a valid name.'), modelValue), model=TRUE)
+#     	    return()
+#    	    }
+#	outcome <- tclvalue(outcomeVariable)
+#	
+#       command_stack <- paste('base <- do.call(rbind.data.frame, ',modelValue,'_aux$mcmc)', sep = "")
+#	justDoIt(command_stack)
+#
+#	if (outcome == 'favor'){
+#	justDoIt(paste('max_base <- apply(base,1,max)',sep = ""))
+#	justDoIt(paste('p_best <- ifelse(base == max_base, 1, 0)',sep = ""))
+#	}
+#	
+#	if (outcome == 'unfavor'){
+#	justDoIt(paste('min_base <- apply(base,1,min)',sep = ""))
+#	justDoIt(paste('p_best <- ifelse(base == min_base, 1, 0)',sep = ""))
+#	}
+#	command <- paste('summary(p_best)', sep="")
+#       doItAndPrint(command)
+#
+	#if (tclvalue(detailVariable) == "1")
+	#{
+	#
+	#if (outcome == 'favor'){
+	#
+	#for (n in 1:Treat-1){
+	#for (y in 2:Treat){
+	#justDoIt(paste('Diffs <- (teste[,',n,'] - teste[,',y,'])',sep = ""))
+	#justDoIt(paste('table(do.call(rbind,lapply(Diffs,function(x) x<=0)))',sep = ""))
+	#}
+	#}
+	#
+	#for (y in 1:Treat){
+	#	justDoIt(paste('exp(quantile(do.call(rbind,MTCModel.1$mcmc)[,',y,'],c(0.1, 0.25, 0.5, 0.75, 0.9)))', sep = ""))
+	#	justDoIt(paste('table(do.call(rbind,lapply(MTCModel.1$mcmc,function(x) x<=0))[,',y,'])', sep = ""))
+	#		  }
+	#
+	#}
+	#
+	#
+	#
+	#if (outcome == 'unfavor'){
+	#	for (n in 1:Treat-1){
+	#		for (y in 2:Treat){
+	#			justDoIt(paste('Diffs <- (teste[,',n,'] - teste[,',y,'])',sep = ""))
+	#			justDoIt(paste('table(do.call(rbind,lapply(Diffs,function(x) x>=0)))',sep = ""))
+	#				  }
+	#			    }
+	#			 }
+	#
+	#
+	#
+	#}
+#	
+#	
+#	tkfocus(CommanderWindow())
+#
+#	               }
+#
+#    OKCancelHelp(helpSubject="run.jags", reset="BestStrat")
+#    tkgrid(labelRcmdr(modelFrame, text = gettextRcmdr("Enter a name for existing model:")), model, sticky = "w")
+#    tkgrid(labelRcmdr(optionsFrame, text=gettextRcmdr("Detailed analysis:")), detailCheckBox, sticky="w")
+    #tkgrid(tklabel(top, text="Number of treatments"), TreatEntry, sticky="e")	
+#    tkgrid(modelFrame, sticky = "w") 
+#    tkgrid(outcomeFrame, sticky="w")  
+#    tkgrid(buttonsFrame, sticky="w")
+#    dialogSuffix()
+#	                }
+
 #------------//------------//------------//------------//------------//------------//------------//------------//------------//------------//------------//------------//------------
 
 DensityPlots <- function(){
@@ -335,6 +412,7 @@ DensityPlots <- function(){
     modelName <- tclVar(paste("MTCModel.", "1", sep = ""))
     modelFrame <- tkframe(top)    
     model <- ttkentry(modelFrame, width = "20", textvariable = modelName) 
+    UpdateModelNumber()
 
     onOK <- function(){
         modelValue <- trim.blanks(tclvalue(modelName))
@@ -362,6 +440,7 @@ ForestPlot <- function(){
     modelName <- tclVar(paste("MTCModel.", "1", sep = ""))
     modelFrame <- tkframe(top)    
     model <- ttkentry(modelFrame, width = "20", textvariable = modelName) 
+    UpdateModelNumber()
 
     onOK <- function(){
         modelValue <- trim.blanks(tclvalue(modelName))
@@ -370,11 +449,11 @@ ForestPlot <- function(){
       	    errorCondition(recall=ForestPlot, message=sprintf(gettextRcmdr('"%s" is not a valid name.'), modelValue), model=TRUE)
       	    return()
     	    } 
-	command <- paste('Teste_ForestPlot <- summary(',modelValue,'_aux2)', sep="")
+	command <- paste('Teste <- summary(',modelValue,'_aux2)', sep="")
         doItAndPrint(command)
-	justDoIt(paste('lod <- Teste_ForestPlot$statistics[,1]', sep=""))
-	justDoIt(paste('sd_lod <- Teste_ForestPlot$statistics[,2]', sep=""))
-	justDoIt(paste('N_Trat <- length(Teste_ForestPlot$statistics[,1])', sep=""))
+	justDoIt(paste('lod <- Teste[,"Mean"]', sep=""))
+	justDoIt(paste('sd_lod <- Teste[,"SD"]', sep=""))
+	justDoIt(paste('N_Trat <- length(Teste[,"Mean"])', sep=""))
 
 	justDoIt(paste('matriz_lor <- outer(lod,lod,"-")', sep=""))
 	justDoIt(paste('LOR <- matriz_lor[lower.tri(matriz_lor)]', sep=""))
@@ -413,15 +492,6 @@ ForestPlot <- function(){
 #------------//------------//------------//------------//------------//------------//------------//------------//------------//------------//------------//------------//------------
 
 Relationship <- function(){
-    
-    modelsVariable = NULL
-    rm(modelsVariable)
-    Size = NULL
-    rm(Size)
-    temp = NULL
-    rm(temp)
-    modelsFrame = NULL
-    rm(modelsFrame)
     Library('igraph')
     initializeDialog(title=gettextRcmdr("Relationship graph"))
     defaults <- list(models="fem")
@@ -480,7 +550,8 @@ GelmanRubinPlot <- function(){
     modelName <- tclVar(paste("MTCModel.", "1", sep = ""))
     modelFrame <- tkframe(top)    
     model <- ttkentry(modelFrame, width = "20", textvariable = modelName) 
-    
+    UpdateModelNumber()
+
     onOK <- function(){
         modelValue <- trim.blanks(tclvalue(modelName))
         closeDialog()      
@@ -488,9 +559,9 @@ GelmanRubinPlot <- function(){
       	    errorCondition(recall=GelmanRubinPlot, message=sprintf(gettextRcmdr('"%s" is not a valid name.'), modelValue), model=TRUE)
       	    return()
     	    } 
-	command <- paste('Teste_GelmanRubin <- summary(',modelValue,'_aux)', sep="")
+	command <- paste('Teste <- summary(',modelValue,'_aux)', sep="")
         justDoIt(command)
-	justDoIt(paste('N_Trat <- length(Teste_GelmanRubin$statistics[,1])', sep=""))
+	justDoIt(paste('N_Trat <- length(Teste[,"Mean"])', sep=""))
 	justDoIt(paste('Teste_d <- ',modelValue,'_aux2$mcmc', sep=""))
 	doItAndPrint(paste('gelman.plot(Teste_d[,2:N_Trat])', sep=""))
 	justDoIt(paste('x11()', sep=""))
